@@ -132,27 +132,29 @@ async fn main() -> Result<()> {
             }
         }
 
-        let icon = match status {
-            Status::Good => "+".green(),
-            Status::Bad => "-".red(),
-            Status::Unknown => "?".yellow(),
-        };
-        println!(
-            "[{icon}] {} {} {} {}",
-            pkg.name,
-            pkg.architecture,
-            pkg.version,
-            status.fancy()
-        );
+        if !args.summary {
+            let icon = match status {
+                Status::Good => "+".green(),
+                Status::Bad => "-".red(),
+                Status::Unknown => "?".yellow(),
+            };
+            println!(
+                "[{icon}] {} {} {} {}",
+                pkg.name,
+                pkg.architecture,
+                pkg.version,
+                status.fancy()
+            );
+        }
     }
 
     if installed.is_empty() {
         eprintln!("Warning: No packages found.");
     } else {
         match negatives {
-            0 => info!("All packages are reproducible!"),
+            0 => info!("All packages have been reproduced!"),
             1 => info!(
-                "1/{} package is {} reproducible.{}",
+                "1/{} package could {} be reproduced.{}",
                 installed.len(),
                 "not".bold(),
                 String::from(if installed.len() > 1 {
@@ -162,14 +164,14 @@ async fn main() -> Result<()> {
                 }),
             ),
             _ => info!(
-                "{}/{} packages are {} reproducible.",
+                "{}/{} packages could {} be reproduced.",
                 negatives,
                 installed.len(),
                 "not".bold(),
             ),
         }
         info!(
-            "Your system is {:.2}% reproducible.",
+            "Your system has {:.2}% been reproduced.",
             ((installed.len() - negatives) as f64 / installed.len() as f64) * 100.
         )
     }
